@@ -85,6 +85,15 @@ class NXOntology(Freezable):
         if not nx.is_directed_acyclic_graph(self.graph):
             raise ValueError("NXOntology requires a directed acyclic graph.")
 
+    @property
+    def name(self) -> Optional[str]:
+        """Short human-readable name for the ontology."""
+        key = self.graph.graph.get("graph_name_attribute", "name")
+        name = self.graph.graph.get(key)
+        if name is not None:
+            return str(name)
+        return None
+
     def write_node_link_json(self, path: str) -> None:
         """
         Serialize to node-link data.
@@ -228,6 +237,39 @@ class NXOntology(Freezable):
         """
         return len(self.graph)
 
+    def set_graph_attributes(
+        self,
+        *,
+        graph_name_attribute: Optional[str] = None,
+        node_label_attribute: Optional[str] = None,
+        node_identifier_attribute: Optional[str] = None,
+        node_url_attribute: Optional[str] = None,
+    ) -> None:
+        """
+        Convenience method to set attributes on the graph that are recognized by nxontology.
+        - graph_name_attribute: graph attribute for looking up the graph's name.
+          Example name of a graph are as 'Metal', 'EFO', 'MeSH'.
+          Defaults to "name" if not set.
+        - node_label_attribute: node attribute for looking up a node's label.
+          Defaults to "label" if not set.
+        - node_identifier_attribute: node attribute for looking up a node's identifier.
+          Defaults to "identifier" if not set.
+        - node_url_attribute: node attribute for looking up a node's URL.
+          Defaults to "url" if not set.
+        Setting the value of `node_*_attribute` arguments to '{node}' specifies using the
+        node itself rather than an attribute. This is helpful for example when nodes are
+        indexed by their identifiers, such that there is no need to include a duplicate
+        identifier node attribute.
+        """
+        if graph_name_attribute:
+            self.graph.graph["graph_name_attribute"] = graph_name_attribute
+        if node_label_attribute:
+            self.graph.graph["node_label_attribute"] = node_label_attribute
+        if node_identifier_attribute:
+            self.graph.graph["node_identifier_attribute"] = node_identifier_attribute
+        if node_url_attribute:
+            self.graph.graph["node_url_attribute"] = node_url_attribute
+
 
 class Node_Info(Freezable):
     """
@@ -252,6 +294,36 @@ class Node_Info(Freezable):
         self.nxo = nxo
         self.node = node
 
+    @property
+    def label(self) -> Optional[str]:
+        """Human readable name / label."""
+        value = self._get_node_attribute(
+            custom_field="node_label_attribute", default="label"
+        )
+        return None if value is None else str(value)
+
+    @property
+    def identifier(self) -> Optional[Any]:
+        """Database / machine identifier."""
+        return self._get_node_attribute(
+            custom_field="node_identifier_attribute", default="identifier"
+        )
+
+    @property
+    def url(self) -> Optional[str]:
+        """Uniform Resource Locator (URL)"""
+        value = self._get_node_attribute(
+            custom_field="node_url_attribute", default="url"
+        )
+        return None if value is None else str(value)
+
+    def _get_node_attribute(self, custom_field: str, default: str) -> Any:
+        """Get node attribute for the attribute set by custom_field or by default."""
+        key = self.nxo.graph.graph.get(custom_field, default)
+        if key == "{node}":
+            return self.node
+        return self.data.get(key)
+
     @property
     def frozen(self) -> bool:
         return self.nxo.frozen
@@ -299,6 +371,17 @@ class Node_Info(Freezable):
         """Number of descendants of node in graph, including itself."""
         return len(self.descendants)
 
+    @property  # type: ignore [misc]
+    @cache_on_frozen
+    def depth(self) -> int:
+        """Minimum shortest path distance from a root node to this node."""
+        depth = min(
+            nx.shortest_path_length(self.nxo.graph, root, self.node)
+            for root in self.ancestors & self.nxo.roots
+        )
+        assert isinstance(depth, int)
+        return depth
+
     @property  # type: ignore [misc]
     @cache_on_frozen
     def intrinsic_ic(self) -> float:
