@@ -12,24 +12,6 @@ from nxontology.exceptions import DuplicateError, NodeNotFound
 from nxontology.ontology import Node_Info, NXOntology, Similarity, SimilarityIC
 
 
-@pytest.fixture
-def metal_nxo() -> NXOntology:
-    """Returns a newly created metal ontology for each test."""
-    return create_metal_nxo()
-
-
-@pytest.fixture(scope="module")
-def metal_nxo_frozen() -> NXOntology:
-    """
-    Frozen metals ontology,
-    scoped such that all tests in this module will receive the same NXOntology instance.
-    Do not use for tests that edit the graph or graph/node/edge data.
-    """
-    metal_nxo = create_metal_nxo()
-    metal_nxo.freeze()
-    return metal_nxo
-
-
 def test_add_node(metal_nxo: NXOntology) -> None:
     assert "brass" not in metal_nxo.graph
     metal_nxo.add_node("brass", color="#b5a642")
@@ -90,11 +72,49 @@ def test_nxontology_leaves(metal_nxo_frozen: NXOntology) -> None:
     assert leaves == {"copper", "gold", "palladium", "platinum", "silver"}
 
 
+def test_node_info_root(metal_nxo_frozen: NXOntology) -> None:
+    """Test metal node_info. Metal is the only root node."""
+    info = metal_nxo_frozen.node_info("metal")
+    assert info.node == "metal"
+    assert info.n_descendants == metal_nxo_frozen.n_nodes
+    assert info.n_ancestors == 1
+    assert info.depth == 0
+
+
 def test_node_info_gold(metal_nxo_frozen: NXOntology) -> None:
+    print(metal_nxo_frozen.graph.graph)
     gold_info = metal_nxo_frozen.node_info("gold")
     assert gold_info.node == "gold"
+    assert gold_info.label == "gold"
+    assert gold_info.identifier is None
+    assert gold_info.url is None
     assert gold_info.n_descendants == 1
     assert gold_info.n_ancestors == 4
+    assert gold_info.depth == 2
+
+
+def test_set_graph_attributes(metal_nxo: NXOntology) -> None:
+    assert metal_nxo.name == "Metals"
+    metal_nxo.graph.nodes["gold"]["metal_label"] = "test_label"
+    metal_nxo.graph.nodes["gold"]["metal_identifier"] = 1
+    metal_nxo.graph.nodes["gold"]["metal_url"] = "https://example.com"
+    metal_nxo.set_graph_attributes(
+        graph_name_attribute="missing_attribute",
+        node_label_attribute="metal_label",
+        node_identifier_attribute="metal_identifier",
+        node_url_attribute="metal_url",
+    )
+    assert metal_nxo.name is None
+    gold_info = metal_nxo.node_info("gold")
+    assert gold_info.node == "gold"
+    assert gold_info.label == "test_label"
+    assert gold_info.identifier == 1
+    assert gold_info.url == "https://example.com"
+    silver_info = metal_nxo.node_info("silver")
+    assert silver_info.node == "silver"
+    assert silver_info.label is None
+    assert silver_info.identifier is None
+    assert silver_info.url is None
 
 
 def test_node_info_not_found(metal_nxo_frozen: NXOntology) -> None:
